@@ -1,8 +1,8 @@
 /*
  * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001-2003 Joop Stakenborg <pa4tu@amsat.org>
+ * Copyright (C) 2001-2004 Joop Stakenborg <pg4i@amsat.org>
  *
- * This program is free oftware; you can redistribute it and/or modify
+ * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
@@ -18,17 +18,21 @@
  */
 
 #if WANT_HAMLIB
+void stop_hamlib (void);
+gboolean start_hamlib (gchar *radio, gchar *device, gint debugmode, gint timervalue);
 GList *riglist_get_list (void);
 gint get_rigid (gchar * rig);
-gchar *getrigmode (gint mode);
-gint get_riginfo (void);
-void loadsmeter (GtkWidget * widget);
-void sethamlibwidgets (gint status);
-gboolean on_smeterdrawingarea_configure_event (GtkWidget * widget,
-					       GdkEventConfigure * event,
-					       gpointer user_data);
-gboolean on_smeterdrawingarea_expose_event (GtkWidget * widget,
-					    GdkEventExpose * event,
-					    gpointer user_data);
+gchar *rigmode (gint mode);
+void get_powerlevel(void);
+void get_mode(void);
+void get_frequency(void);
+void get_ptt(void);
+void get_smeter(void);
+void get_riginfo (void);
+gint poll_riginfo (void);
+void sethamlibwidgets (gint status, gboolean initsmeter);
+GString *convert_frequency (void);
+gboolean on_smeterdrawingarea_configure_event (GtkWidget * widget, GdkEventConfigure * event, gpointer user_data);
+gboolean on_smeterdrawingarea_expose_event (GtkWidget * widget, GdkEventExpose * event, gpointer user_data);
 void on_mainwindow_show (GtkWidget * widget, gpointer user_data);
 #endif
