@@ -1,6 +1,6 @@
 /*
  * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001-2003 Joop Stakenborg <pa4tu@amsat.org>
+ * Copyright (C) 2001-2004 Joop Stakenborg <pg4i@amsat.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -37,29 +37,29 @@ GList *searchhistory;
 void
 loadhistory (void)
 {
-  gchar *historyfile, history[1024], **histsplit = NULL;
-  FILE *fp;
+	gchar *historyfile, history[1024], **histsplit = NULL;
+	FILE *fp;
 
-  historyfile = g_strconcat (xlogdir, G_DIR_SEPARATOR_S, "history", NULL);
-  fp = fopen (historyfile, "r");
-  if (fp != NULL)
-    {
-      while (!feof (fp))
+	historyfile = g_strconcat (xlogdir, G_DIR_SEPARATOR_S, "history", NULL);
+	fp = fopen (historyfile, "r");
+	if (fp != NULL)
+		{
+			while (!feof (fp))
 	{
-	  if (fscanf (fp, "%s", history) == EOF)
-	    break;
-	  histsplit = g_strsplit (history, ":", 1);
-	  if (!g_strcasecmp (histsplit[0], "se"))
-	    {
-	      g_strdelimit (histsplit[1], "_", ' ');
-	      searchhistory =
+		if (fscanf (fp, "%s", history) == EOF)
+			break;
+		histsplit = g_strsplit (history, ":", -1);
+		if (!g_ascii_strcasecmp (histsplit[0], "se"))
+			{
+				g_strdelimit (histsplit[1], "_", ' ');
+				searchhistory =
 		g_list_append (searchhistory, g_strdup (histsplit[1]));
-	    }
-	  g_strfreev (histsplit);
+			}
+		g_strfreev (histsplit);
 	}
-      fclose (fp);
-    }
-  g_free (historyfile);
+			fclose (fp);
+		}
+	g_free (historyfile);
 }
 
 /*
@@ -68,29 +68,29 @@ loadhistory (void)
 void
 savehistory (void)
 {
-  gchar *historyfile;
-  FILE *fp;
-  guint i, n;
-  gchar *search;
+	gchar *historyfile;
+	FILE *fp;
+	guint i, n;
+	gchar *search;
 
-  historyfile = g_strconcat (xlogdir, G_DIR_SEPARATOR_S, "history", NULL);
-  if ((g_list_length (searchhistory) > 0))
-    {
-      fp = fopen (historyfile, "w");
-      if (fp != NULL)
-	{
-	  if ((n = g_list_length (searchhistory)) > 0)
-	    {
-	      for (i = 0; i < n; i++)
+	historyfile = g_strconcat (xlogdir, G_DIR_SEPARATOR_S, "history", NULL);
+	if ((g_list_length (searchhistory) > 0))
 		{
-		  search = g_list_nth_data (searchhistory, i);
-		  g_strdelimit (search, " ", '_');
-		  fprintf (fp, "se:%s\n", search);
-		  g_free (search);
+			fp = fopen (historyfile, "w");
+			if (fp != NULL)
+	{
+		if ((n = g_list_length (searchhistory)) > 0)
+			{
+				for (i = 0; i < n; i++)
+		{
+			search = g_list_nth_data (searchhistory, i);
+			g_strdelimit (search, " ", '_');
+			fprintf (fp, "se:%s\n", search);
+			g_free (search);
 		}
-	    }
-	  fclose (fp);
+			}
+		fclose (fp);
 	}
-    }
-  g_free (historyfile);
+		}
+	g_free (historyfile);
 }
