@@ -1,8 +1,8 @@
 /*
  * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001-2003 Joop Stakenborg <pa4tu@amsat.org>
+ * Copyright (C) 2001-2004 Joop Stakenborg <pg4i@amsat.org>
  *
- * This program is free oftware; you can redistribute it and/or modify
+ * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
@@ -26,20 +26,20 @@
 /* struct for every log window */
 typedef struct logtype
 {
-  GtkWidget *scrolledwindow;
-  GtkWidget *clist;
-  GtkWidget *label;
-  gchar *logname;
-  gboolean logchanged;
-  gint qsos;
-  gint columns;
-  gint logfields[QSO_FIELDS];
+	GtkWidget *scrolledwindow;
+	GtkWidget *treeview;
+	GtkWidget *label;
+	gchar *logname;
+	gboolean logchanged;
+	gint qsos;
+	gint columns;
+	gint logfields[QSO_FIELDS];
 }
 logtype;
 
-
+void backuplog (gchar *filename, gchar *backupfilename);
 gchar *logname (gchar * filename);
-gint fillin_clist (LOGDB * handle, qso_t q[], gpointer arg);
+gint fillin_list (LOGDB * handle, qso_t q[], gpointer arg);
 logtype *openlog (LOGDB * lp, gchar * name, gint page);
-void savelog (gpointer arg, gchar * logfile, gint type);
-GString *getlogs (gchar * dir, gint filetype);
+void savelog (gpointer arg, gchar * logfile, gint type, gint first, gint last);
+GString *getlogs (gchar * dir, gchar *patt);
