@@ -1,8 +1,8 @@
 /*
  * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001-2003 Joop Stakenborg <pa4tu@amsat.org>
+ * Copyright (C) 2001-2004 Joop Stakenborg <pg4i@amsat.org>
  *
- * This program is free oftware; you can redistribute it and/or modify
+ * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
@@ -17,10 +17,6 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-#ifdef HAVE_CONFIG_H
-#   include <config.h>
-#endif
-
 #include <stdio.h>
 #include <string.h>
 #include <glib.h>
@@ -46,6 +42,9 @@ extern const struct log_ops twlog_ops;
 extern const struct log_ops adif_ops;
 extern const struct log_ops cabrillo_ops;
 extern const struct log_ops editest_ops;
+extern const struct log_ops trlog_ops;
+extern const struct log_ops edi_ops;
+extern const struct log_ops labels_ops;
 
 LOGDB *
 log_file_open (const gchar * path, enum log_file_type type)
@@ -76,6 +75,15 @@ log_file_open (const gchar * path, enum log_file_type type)
     case TYPE_EDITEST:
       handle->ops = &editest_ops;
       break;
+    case TYPE_EDI:
+      handle->ops = &edi_ops;
+      break;
+    case TYPE_TRLOG:
+      handle->ops = &trlog_ops;
+      break;
+    case TYPE_LABELS:
+      handle->ops = &labels_ops;
+      break;
     default:
       /* unsupported log file type */
       g_free (handle);
@@ -123,6 +131,15 @@ log_file_create (const gchar * path, enum log_file_type type,
     case TYPE_EDITEST:
       handle->ops = &editest_ops;
       break;
+    case TYPE_EDI:
+      handle->ops = &edi_ops;
+      break;
+    case TYPE_TRLOG:
+      handle->ops = &trlog_ops;
+      break;
+    case TYPE_LABELS:
+      handle->ops = &labels_ops;
+      break;
     default:
       /* unsupported log file type */
       g_free (handle);
