@@ -1,8 +1,8 @@
 /*
  * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001-2003 Joop Stakenborg <pa4tu@amsat.org>
+ * Copyright (C) 2001-2004 Joop Stakenborg <pg4i@amsat.org>
  *
- * This program is free oftware; you can redistribute it and/or modify
+ * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
@@ -40,15 +40,18 @@ typedef gchar *qso_t;
 struct log_file;
 typedef struct log_file LOGDB;
 
+/* Keep enums in same order as menu in callbacks_menu.c */
 enum log_file_type
 {
-  TYPE_OLD_LOG,			/* version 0.4 and 0.5 */
-  TYPE_FLOG,			/* flexible xlog format */
-  TYPE_TWLOG,
-  TYPE_ADIF,
-  TYPE_CABRILLO,
-  TYPE_EDITEST,
-/*	TYPE_DB3	to be defined */
+	TYPE_OLD_LOG,			/* version 0.4 and 0.5 */
+	TYPE_FLOG,			/* flexible xlog format */
+	TYPE_TWLOG,
+	TYPE_ADIF,
+	TYPE_CABRILLO,
+	TYPE_EDITEST,			/* French contest logger */
+	TYPE_TRLOG,
+	TYPE_EDI,		/* Electronic Data Interchange, IARU Region 1 */
+	TYPE_LABELS, /* Tab separated export of some fields for glabels */
 };
 
 /*
@@ -56,42 +59,38 @@ enum log_file_type
  */
 struct log_ops
 {
-  gint (*open) (LOGDB *);
-  void (*close) (LOGDB *);
-    gint (*create) (LOGDB *);
-    gint (*add_column) (LOGDB *, gint pos, gint field, gint width);
-    gint (*delete_column) (LOGDB *, gint pos);
-    gint (*qso_append) (LOGDB *, const qso_t *);
-    gint (*qso_foreach) (LOGDB *, gint (*fn) (LOGDB *, qso_t *, gpointer arg),
-			 gpointer arg);
-  enum log_file_type type;
-  const char *name;
-  const char *extension;
+	gint (*open) (LOGDB *);
+	void (*close) (LOGDB *);
+	gint (*create) (LOGDB *);
+	gint (*add_column) (LOGDB *, gint pos, gint field, gint width);
+	gint (*delete_column) (LOGDB *, gint pos);
+	gint (*qso_append) (LOGDB *, const qso_t *);
+	gint (*qso_foreach) (LOGDB *, gint (*fn) (LOGDB *, qso_t *, gpointer arg), gpointer arg);
+	enum log_file_type type;
+	const char *name;
+	const char *extension;
 };
 
 struct log_file
 {
-  enum log_file_type type;
-  const struct log_ops *ops;
-  gchar *path;
-  gpointer priv;		/* for use by the log backend */
-  gint column_nr;
-  gint column_fields[MAX_COLUMN];
-  gint column_widths[MAX_COLUMN];
+	enum log_file_type type;
+	const struct log_ops *ops;
+	gchar *path;
+	gpointer priv;		/* for use by the log backend */
+	gint column_nr;
+	gint column_fields[MAX_COLUMN];
+	gint column_widths[MAX_COLUMN];
 };
 
 LOGDB *log_file_open (const gchar * path, enum log_file_type type);
 LOGDB *log_file_create (const gchar * path, enum log_file_type type,
-			gint columns, const gint column_field[],
-			const gint column_width[]);
+		gint columns, const gint column_field[], const gint column_width[]);
 void log_file_close (LOGDB *);
 gint log_file_add_column (LOGDB *, gint pos, gint field, gint width);
 gint log_file_delete_column (LOGDB *, gint pos);
-
 gint log_file_qso_append (LOGDB *, const qso_t *);
 gint log_file_qso_foreach (LOGDB *,
-			   gint (*fn) (LOGDB *, qso_t *, gpointer arg),
-			   gpointer arg);
+		gint (*fn) (LOGDB *, qso_t *, gpointer arg), gpointer arg);
 /*
 	qso_t* get_qso_from_nr(nr)
 	update_qso(nr, qso_t)
