@@ -1,8 +1,8 @@
 /*
  * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001-2003 Joop Stakenborg <pa4tu@amsat.org>
+ * Copyright (C) 2001-2004 Joop Stakenborg <pg4i@amsat.org>
  *
- * This program is free oftware; you can redistribute it and/or modify
+ * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
@@ -21,10 +21,6 @@
  * oldlog.c - support for v0.4 and v0.5 flat file format
  */
 
-#ifdef HAVE_CONFIG_H
-#	include <config.h>
-#endif
-
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
@@ -52,14 +48,14 @@ static gint old_log_qso_foreach (LOGDB *,
 				 gpointer arg);
 
 const struct log_ops old_log_ops = {
-  open:old_log_open,
-  close:old_log_close,
-  create:old_log_create,
-  qso_append:old_log_qso_append,
-  qso_foreach:old_log_qso_foreach,
-  type:TYPE_OLD_LOG,
-  name:"Oldlog",
-  extension:".log",
+  .open = old_log_open,
+  .close = old_log_close,
+  .create = old_log_create,
+  .qso_append = old_log_qso_append,
+  .qso_foreach = old_log_qso_foreach,
+  .type = TYPE_OLD_LOG,
+  .name = "Oldlog",
+  .extension = ".log",
 };
 
 /*
