@@ -1,8 +1,8 @@
 /*
  * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001-2003 Joop Stakenborg <pa4tu@amsat.org>
+ * Copyright (C) 2001-2004 Joop Stakenborg <pg4i@amsat.org>
  *
- * This program is free oftware; you can redistribute it and/or modify
+ * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
@@ -21,10 +21,6 @@
  * twlog.c - support for WA0EIR Ted's twlog file format, as of v1.3
  */
 
-#ifdef HAVE_CONFIG_H
-#	include <config.h>
-#endif
-
 #include <stdlib.h>
 #include <string.h>
 #include <stdio.h>
@@ -52,14 +48,14 @@ static gint twlog_qso_foreach (LOGDB *,
 			       gpointer arg);
 
 const struct log_ops twlog_ops = {
-  open:twlog_open,
-  close:twlog_close,
-  create:twlog_create,
-  qso_append:twlog_qso_append,
-  qso_foreach:twlog_qso_foreach,
-  type:TYPE_TWLOG,
-  name:"Twlog",
-  extension:"",
+  .open = twlog_open,
+  .close = twlog_close,
+  .create = twlog_create,
+  .qso_append = twlog_qso_append,
+  .qso_foreach = twlog_qso_foreach,
+  .type = TYPE_TWLOG,
+  .name = "Twlog",
+  .extension = "",
 };
 
 /*
@@ -69,15 +65,17 @@ gint
 twlog_open (LOGDB * handle)
 {
   FILE *fp;
+	const gint xlog_fields [] = {DATE, GMT, GMTEND, CALL, BAND, MODE, RST, MYRST, POWER, REMARKS};
 
   fp = fopen (handle->path, "r");
   if (!fp)
     return -1;
   handle->priv = (gpointer) fp;
 
-  handle->column_nr = twlog_field_nr;
-  memcpy (handle->column_fields, twlog_fields, sizeof (twlog_fields));
-  memcpy (handle->column_widths, twlog_widths, sizeof (twlog_widths));
+	/* set columns to be used in xlog */
+  handle->column_nr = 10;
+  memcpy (handle->column_fields, xlog_fields, sizeof (xlog_fields));
+  /* TODO: set and use handle->column_widths */
 
   return 0;
 }
