@@ -1,8 +1,8 @@
 /*
  * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001-2003 Joop Stakenborg <pa4tu@amsat.org>
+ * Copyright (C) 2001-2004 Joop Stakenborg <pg4i@amsat.org>
  *
- * This program is free oftware; you can redistribute it and/or modify
+ * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
@@ -26,7 +26,6 @@ void updateoptionmenu (GtkWidget * optionmenu, gchar ** split);
 void deletespaces (gchar ** split);
 void update_statusbar (gchar * string);
 gboolean remove_prefixes (gchar * key, gpointer value, gpointer user_data);
-gboolean latexavailable (void);
 void save_windowsize_and_cleanup (void);
 gchar *finddot (gchar * qsoband);
 gchar *findint (gchar * freq);
@@ -37,11 +36,8 @@ gchar *lookup_mode (gchar * selectedmode);
 gchar *lookup_band (gchar * selectedband);
 gint updateclock (void);
 gchar *color_parse (gchar * value);
-void setcallstyle (GtkWidget * clist, gint row, gchar * color, gchar * font);
 gchar *getlabelcolor (GtkWidget * label);
-void setlabelstyle (GtkWidget * label, gchar * color, gchar * font);
-void setframestyle (GtkWidget * frame, gchar * color, gchar * font);
 gint autosave (void);
 void set_qsoframe (gpointer arg);
 gboolean fileexist (gchar * path);
-gchar *strreplace (gchar * str, const gchar * from, const gchar * to);
+gchar *my_strreplace(gchar *str, const gchar *from, const gchar *to);
